==> zio-aws-codestarnotifications_3-5.17.147.1-sources.jar: zio/aws/codestarnotifications/model/ListNotificationRulesRequest.scala <==
package zio.aws.codestarnotifications.model
import java.lang.Integer
import zio.ZIO
import zio.aws.codestarnotifications.model.primitives.{MaxResults, NextToken}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListNotificationRulesRequest(
    filters: Option[
      Iterable[zio.aws.codestarnotifications.model.ListNotificationRulesFilter]
    ] = None,
    nextToken: Option[NextToken] = None,
    maxResults: Option[MaxResults] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codestarnotifications.model.ListNotificationRulesRequest = {
    import ListNotificationRulesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codestarnotifications.model.ListNotificationRulesRequest
      .builder()
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.codestarnotifications.model.ListNotificationRulesRequest.ReadOnly =
    zio.aws.codestarnotifications.model.ListNotificationRulesRequest
      .wrap(buildAwsValue())
}
object ListNotificationRulesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codestarnotifications.model.ListNotificationRulesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.codestarnotifications.model.ListNotificationRulesRequest =
      zio.aws.codestarnotifications.model.ListNotificationRulesRequest(
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def filters: Option[List[
      zio.aws.codestarnotifications.model.ListNotificationRulesFilter.ReadOnly
    ]]
    def nextToken: Option[NextToken]
    def maxResults: Option[MaxResults]
    def getFilters: ZIO[Any, AwsError, List[
      zio.aws.codestarnotifications.model.ListNotificationRulesFilter.ReadOnly
    ]] = AwsError.unwrapOptionField("filters", filters)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codestarnotifications.model.ListNotificationRulesRequest
  ) extends zio.aws.codestarnotifications.model.ListNotificationRulesRequest.ReadOnly {
    override val filters: Option[List[
      zio.aws.codestarnotifications.model.ListNotificationRulesFilter.ReadOnly
    ]] = scala
      .Option(impl.filters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.codestarnotifications.model.ListNotificationRulesFilter
            .wrap(item)
        }.toList
      )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value =>
        zio.aws.codestarnotifications.model.primitives.NextToken(value)
      )
    override val maxResults: Option[MaxResults] = scala
      .Option(impl.maxResults())
      .map(value =>
        zio.aws.codestarnotifications.model.primitives.MaxResults(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.codestarnotifications.model.ListNotificationRulesRequest
  ): zio.aws.codestarnotifications.model.ListNotificationRulesRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-codestarnotifications_3-5.20.22.2-sources.jar: zio/aws/codestarnotifications/model/ListNotificationRulesRequest.scala <==
package zio.aws.codestarnotifications.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.codestarnotifications.model.primitives.{MaxResults, NextToken}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class ListNotificationRulesRequest(
    filters: Optional[
      Iterable[zio.aws.codestarnotifications.model.ListNotificationRulesFilter]
    ] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent,
    maxResults: Optional[MaxResults] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codestarnotifications.model.ListNotificationRulesRequest = {
    import ListNotificationRulesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codestarnotifications.model.ListNotificationRulesRequest
      .builder()
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.codestarnotifications.model.ListNotificationRulesRequest.ReadOnly =
    zio.aws.codestarnotifications.model.ListNotificationRulesRequest
      .wrap(buildAwsValue())
}
object ListNotificationRulesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codestarnotifications.model.ListNotificationRulesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.codestarnotifications.model.ListNotificationRulesRequest =
      zio.aws.codestarnotifications.model.ListNotificationRulesRequest(
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def filters: Optional[List[
      zio.aws.codestarnotifications.model.ListNotificationRulesFilter.ReadOnly
    ]]
    def nextToken: Optional[NextToken]
    def maxResults: Optional[MaxResults]
    def getFilters: ZIO[Any, AwsError, List[
      zio.aws.codestarnotifications.model.ListNotificationRulesFilter.ReadOnly
    ]] = AwsError.unwrapOptionField("filters", filters)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codestarnotifications.model.ListNotificationRulesRequest
  ) extends zio.aws.codestarnotifications.model.ListNotificationRulesRequest.ReadOnly {
    override val filters: Optional[List[
      zio.aws.codestarnotifications.model.ListNotificationRulesFilter.ReadOnly
    ]] = zio.aws.core.internal
      .optionalFromNullable(impl.filters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.codestarnotifications.model.ListNotificationRulesFilter
            .wrap(item)
        }.toList
      )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value =>
        zio.aws.codestarnotifications.model.primitives.NextToken(value)
      )
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value =>
        zio.aws.codestarnotifications.model.primitives.MaxResults(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.codestarnotifications.model.ListNotificationRulesRequest
  ): zio.aws.codestarnotifications.model.ListNotificationRulesRequest.ReadOnly =
    new Wrapper(impl)
}
